@@ -15,9 +15,9 @@
 #  License along with this library.
 
 PROJECT_NAME = "OctoBot-CLI"
-VERSION = "1.0.2"  # major.minor.revision
+VERSION = "1.0.7"  # major.minor.revision
 
-OCTOBOT_PACKAGE = "OctoBot >= 0.4.0a9"
+OCTOBOT_PACKAGE = "OctoBot >= 0.4.0b"
 
 DEFAULT_VENV_PATH = "venv"
 
@@ -25,6 +25,7 @@ OCTOBOT_IMAGE = "drakkarsoftware/octobot"
 OCTOBOT_PI_IMAGE = "drakkarsoftware/octobot-pi"
 OCTOBOT_CONTAINER_NAME = "octobot"
 OCTOBOT_LATEST_TAG = "latest"
-OCTOBOT_STABLE_TAG = "0.4.0"  # TODO change it
+OCTOBOT_STABLE_TAG = "0.4.0-stable"
+OCTOBOT_STABLE_NIGHTLY = "0.4.0"
 
 CONTAINER_DEFAULT_PUBLISH_PORT = 5001
